/**
 *  @des: JS调用原生功能方法集合
 */
var objKxb = {

    /* ------- 获取设备uuid ------- */
    getUuid() {
        if(typeof(kxbApp) == 'undefined') return;

        let sUuid = kxbApp.getUid();
        return sUuid;
    },

    /* ------- 拍照/相册选择图片 ------- */
    chooseImage(callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            count: 1,
            sourceType : ['album', 'camera'],
            base64Flag: 1,
            success : 'chooseImageCallBack'
        });

        window['chooseImageCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);

            if(oRes.retCode == 0) {
                let sFilePath = oRes.ids[0];
                let sBase64 = oRes.base64s[0];
                callback(sFilePath, sBase64);
            }
        }

        kxbApp.chooseImage(jsonParams);
    },

    /* ------- 上传本地图片 ------- */
    uploadImage(url, params, callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            url: url,
            params: params,
            success: 'uploadImageCallBack'
        });

        window['uploadImageCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);

            if(oRes.retCode == 0) {
                let sUrl = oRes.serverUrl;
                callback(sUrl);
            }
        }

        kxbApp.uploadImage(jsonParams);
    },

    /* ------- 原生分享 ------- */
    shareMedia(type, params, callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            mediaType: type,
            data: params,
            success: 'shareMediaCallBack'
        });

        window['shareMediaCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        kxbApp.shareMedia(jsonParams);
    },

    /* ------- 打开新URL ------- */
    openWindow(params, callback, closeback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            title: params.title,
            url: params.url,
            success: 'openWindowCallBack',
            closed: 'closeWindowCallBack'
        });

        window['openWindowCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        window['closeWindowCallBack'] = () => {
            return closeback();
        }

        kxbApp.openWindow(jsonParams);
    },

    /* ------- 关闭新打开的URL ------- */
    closeWindow() {
        typeof(kxbApp) != 'undefined' && kxbApp.closeWindow();
    },

    /* ------- 退出应用 ------- */
    exitApp() {
        typeof(kxbApp) != 'undefined' && kxbApp.exitApp();
    },

    /* ------- 拨打电话 ------- */
    makeCall(params, callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            phoneNumber: params.phoneNumber,
            success : 'makeCallCallBack',
        });

        window['makeCallCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        kxbApp.makeCall(jsonParams);
    },

    /* ------- 发送短信 ------- */
    sendSMS(params, callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            phoneNumber: params.phoneNumber,
            content: params.content,
            success : 'sendSMSCallBack',
        });

        window['sendSMSCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        kxbApp.sendSMS(jsonParams);
    },

    /* ------- 设置本地数据缓存 ------- */
    setAppCache(key, data) {
        typeof(kxbApp) != 'undefined' && kxbApp.setAppCache(key, data);
    },

    /* ------- 获取本地数据缓存 ------- */
    getAppCache(key) {
        if(typeof(kxbApp) == 'undefined') return;

        let data = kxbApp.getAppCache(key);
        return data;
    },

    /* ------- 清除指定数据缓存 ------- */
    clearAppCache(params, callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            keys: params.keys,
            success : 'clearAppCacheCallBack'
        });

        window['clearAppCacheCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        kxbApp.clearAppCache(jsonParams);
    },

    /* ------- 清除应用缓存（图片和数据的缓存） ------- */
    clearAllCache(callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            'success' : 'clearAllCacheCallBack'
        });

        window['clearAllCacheCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        kxbApp.clearAllCache(jsonParams);
    },

    /* ------- 获取应用缓存值（图片和数据的缓存） ------- */
    getCacheSize() {
        if(typeof(kxbApp) == 'undefined') return;

        let nSize = kxbApp.getCacheSize();
        return nSize;
    },

    /* ------- 原生支付 ------- */
    openPay(url, params, callback) {
       if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            url: url,
            params: params,
            success: 'openPayCallBack'
        });

        window['openPayCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);

            if(oRes.retCode == 0) {
                let sOrdersn = oRes.ordersn;
                let sPrice = oRes.oRes.price;
                callback(sOrdersn, sPrice);
            }
        }

        kxbApp.openPay(jsonParams);
    },

    /* ------- 小能客服 ------- */
    openXiaoNeng(params, callback) {
        if(typeof(kxbApp) == 'undefined') return;

        let jsonParams = JSON.stringify({
            params: params,
            success: 'oepnXiaoNengCallBack'
        });

        window['oepnXiaoNengCallBack'] = (res) => {
            let oRes = typeof(res) == 'object' ? res : JSON.parse(res);
            oRes.retCode == 0 && callback();
        }

        kxbApp.openXiaoNeng(jsonParams);
    }

};